@@ -973,6 +973,8 @@ yaml_syck_emitter_handler
                         syck_emit_item( e, (st_data_t)val );
                     }
                 }
+                // reset hash each poiter
+                hv_iterinit(hv);
                 syck_emit_end(e);
                 return;
             }
